==> phoenix-starter-scheduling-0.1.2-20230913.084631-1-sources.jar: com/elitesland/cbpl/scheduling/entity/ScheduleInstanceDO.java <==
package com.elitesland.cbpl.scheduling.entity;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.elitescloud.boot.model.entity.BaseModel;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;
import javax.persistence.*;
import lombok.experimental.Accessors;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * 定时任务实例表
 *
 * @author eric.hao
 * @since 2023/09/12
 */
@Data
@DynamicInsert
@DynamicUpdate
@Accessors(chain = true)
@Entity
@Table(name = "sys_schedule_instance")
@org.hibernate.annotations.Table(appliesTo = "sys_schedule_instance", comment = "定时任务实例表")
@ApiModel("定时任务实例表")
public class ScheduleInstanceDO extends BaseModel implements Serializable {

	private static final long serialVersionUID = 2670209428121358520L;

	/**
	 * 任务ID
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "任务ID")
	@Column(name = "mas_id", nullable = true, length = 20)
	private Long masId;

	/**
	 * 日志行状态
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "日志行状态")
	@Column(name = "instance_status", nullable = true, length = 2)
	private String instanceStatus;

	/**
	 * 错误日志
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "错误日志")
	@Column(name = "error_message", nullable = true, length = 255)
	private String errorMessage;

	/**
	 * 开始时间
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "开始时间")
	@Column(name = "start_time", nullable = true)
	private LocalDateTime startTime;

	/**
	 * 结束时间
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "结束时间")
	@Column(name = "end_time", nullable = true)
	private LocalDateTime endTime;
}

==> phoenix-starter-scheduling-0.1.4.6-20240117.074246-1-sources.jar: com/elitesland/cbpl/scheduling/entity/ScheduleInstanceDO.java <==
package com.elitesland.cbpl.scheduling.entity;

import com.elitesland.cbpl.tool.db.entity.BaseEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;
import javax.persistence.*;
import lombok.experimental.Accessors;
import lombok.Data;

import java.io.Serializable;
import java.time.LocalDateTime;

/**
 * 定时任务实例表
 *
 * @author eric.hao
 * @since 2023/09/12
 */
@Data
@DynamicInsert
@DynamicUpdate
@Accessors(chain = true)
@Entity
@Table(name = "sys_schedule_instance")
@org.hibernate.annotations.Table(appliesTo = "sys_schedule_instance", comment = "定时任务实例表")
@ApiModel("定时任务实例表")
public class ScheduleInstanceDO extends BaseEntity implements Serializable {

	private static final long serialVersionUID = 2670209428121358520L;

	/**
	 * 任务ID
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "任务ID")
	@Column(name = "mas_id", nullable = true, length = 20)
	private Long masId;

	/**
	 * 日志行状态
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "日志行状态")
	@Column(name = "instance_status", nullable = true, length = 2)
	private String instanceStatus;

	/**
	 * 错误日志
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "错误日志")
	@Column(name = "error_message", nullable = true, length = 255)
	private String errorMessage;

	/**
	 * 开始时间
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "开始时间")
	@Column(name = "start_time", nullable = true)
	private LocalDateTime startTime;

	/**
	 * 结束时间
	 * nullable : true
	 * default  : null
	 */
	@ApiModelProperty(value = "结束时间")
	@Column(name = "end_time", nullable = true)
	private LocalDateTime endTime;
}
